summaryrefslogtreecommitdiffstats
path: root/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kate/cppsymbolviewer/plugin_katesymbolviewer.cpp')
-rw-r--r--kate/cppsymbolviewer/plugin_katesymbolviewer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp b/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
index 39abc4a..d12bb99 100644
--- a/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
+++ b/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
@@ -14,7 +14,7 @@
* Jun 19 2003 v.1.0 - Removed TQTimer (polling is Evil(tm)... )
* - Captured documentChanged() event to refresh symbol list
* - Tooltips vanished into nowhere...sigh :(
* May 04 2003 v 0.6 - Symbol List becomes a KListView object. Removed Tooltip class.
* Added a TQTimer that every 200ms checks:
* * if the list width has changed
* * if the document has changed
@@ -55,7 +55,7 @@ K_EXPORT_COMPONENT_FACTORY( katecppsymbolviewerplugin, KGenericFactory<KatePlugi
KatePluginSymbolViewerView::KatePluginSymbolViewerView(Kate::MainWindow *w)
{
TDEGlobal::locale()->insertCatalogue("katecppsymbolviewer");
- KToggleAction* act = new KToggleAction ( i18n("Hide Symbols"), 0, this, TQT_SLOT( slotInsertSymbol() ), actionCollection(), "view_insert_symbolviewer" );
+ TDEToggleAction* act = new TDEToggleAction ( i18n("Hide Symbols"), 0, this, TQT_SLOT( slotInsertSymbol() ), actionCollection(), "view_insert_symbolviewer" );
act->setCheckedState(i18n("Show Symbols"));
setInstance (new TDEInstance("kate"));
@@ -123,7 +123,7 @@ void KatePluginSymbolViewerView::slotInsertSymbol()
{
dock = win->toolViewManager()->createToolView("kate_plugin_cppsymbolviewer", Kate::ToolViewManager::Left, cls, i18n("Symbol List"));
- symbols = new KListView(dock);
+ symbols = new TDEListView(dock);
treeMode = 0;
connect(symbols, TQT_SIGNAL(executed(TQListViewItem *)), this, TQT_SLOT(goToSymbol(TQListViewItem *)));
@@ -14,7 +14,7 @@
* - Captured documentChanged() event to refresh symbol list
* - Tooltips vanished into nowhere...sigh :(
- * May 04 2003 v 0.6 - Symbol List becomes a KListView object. Removed Tooltip class.
+ * May 04 2003 v 0.6 - Symbol List becomes a TDEListView object. Removed Tooltip class.
* Added a TQTimer that every 200ms checks:
* * if the list width has changed